@@ -22,12 +22,12 @@ class Option(object):
         return l
 
 
-@pytest.fixture(params=['normal', '1 slave', '2 slave'])
+@pytest.fixture(params=['normal', '1 worker', '2 worker'])
 def n(request):
     return {
         'normal': None,
-        '1 slave': 1,
-        '2 slave': 2,
+        '1 worker': 1,
+        '2 worker': 2,
     }[request.param]
 
 
@@ -163,7 +163,7 @@ class TestInstafailingTerminalReporter(object):
                 "*setup func*",
                 "*assert 0*",
                 "test_error_in_setup_then_pass.py:4: AssertionError",
-                ".",
+                ".*",
             ])
         else:
             result.stdout.fnmatch_lines([
@@ -174,7 +174,7 @@ class TestInstafailingTerminalReporter(object):
                 "*assert 0*",
                 "test_error_in_setup_then_pass.py:4: AssertionError",
                 "",
-                "*test_error_in_setup_then_pass.py .",
+                "*test_error_in_setup_then_pass.py .*",
                 "*1 error*",
             ])
         assert result.ret != 0
@@ -214,7 +214,7 @@ class TestInstafailingTerminalReporter(object):
                 "*teardown func*",
                 "*assert 0*",
                 "test_error_in_teardown_then_pass.py:4: AssertionError",
-                ".",
+                ".*",
             ])
         else:
             result.stdout.fnmatch_lines([
@@ -225,7 +225,7 @@ class TestInstafailingTerminalReporter(object):
                 "*assert 0*",
                 "test_error_in_teardown_then_pass.py:4: AssertionError",
                 "",
-                "*test_error_in_teardown_then_pass.py .",
+                "*test_error_in_teardown_then_pass.py .*",
                 "*1 error*",
             ])
         assert result.ret != 0
@@ -241,7 +241,7 @@ class TestInstafailingTerminalReporter(object):
         ])
         if not option.quiet:
             result.stdout.fnmatch_lines([
-                "collected 0 items / 1 errors",
+                "collected 0 items / 1 error*",
             ])
 
     def test_print_stacktrace_once_with_pdb(self, testdir, request, option):
@@ -258,7 +258,7 @@ class TestInstafailingTerminalReporter(object):
         child = testdir.spawn_pytest(' '.join(args))
         child.expect('>+ traceback >+')
 
-        assert 'E       assert 0' not in child.before
+        assert b'E       assert 0' not in child.before
 
         child.expect('(Pdb)')
         child.sendeof()
@@ -277,14 +277,14 @@ class TestInstafailingTerminalReporter(object):
         result = testdir.runpytest(*option.args)
         if option.verbose:
             result.stdout.fnmatch_lines([
-                "test_xfail_unexpected_success.py:*:*test_func XPASS"
+                "test_xfail_unexpected_success.py:*:*test_func XPASS*"
             ])
         elif option.quiet:
             result.stdout.fnmatch_lines([
-                "X"
+                "X*"
             ])
         else:
             result.stdout.fnmatch_lines([
-                "test_xfail_unexpected_success.py X"
+                "test_xfail_unexpected_success.py X*"
             ])
         assert "INTERNALERROR" not in result.stdout.str()
